PyViennaCL Example Code
=======================

.. toctree::
   :maxdepth: 1

   basics.rst
   products.rst
   slices-and-proxies.rst
   sparse-matrices.rst
   iterative-solvers.rst
   direct-solvers.rst

